pub fn default_registry() -> Result<CapabilityRegistry, EngineError>Expand description
Builds the maintained trusted capability registry.
Errors
Returns an error if two maintained capabilities declare the same stable ID.
pub fn default_registry() -> Result<CapabilityRegistry, EngineError>Builds the maintained trusted capability registry.
Returns an error if two maintained capabilities declare the same stable ID.